@@ -1,4 +1,4 @@
-from pysyncobj import SyncObj, SyncObjConf, FAIL_REASON
+from pysyncobj import SyncObj, SyncObjConf, FAIL_REASON, SyncObjException
 from pysyncobj.batteries import ReplLockManager, ReplDict
 from typing import Optional
 from collections import defaultdict
@@ -19,6 +19,7 @@ class LANPrintQueueBase(SyncObj):
       self._logger = logger
       self._logger.debug("LANPrintQueueBase init")
       self.ns = ns
+      self.acquire_timeout = 5
       self.addr = addr
       if basedir is not None:
           self.basedir = Path(basedir)
@@ -66,7 +67,10 @@ class LANPrintQueueBase(SyncObj):
       del self.jobs[hash_]
 
     def acquireJob(self, hash_: str):
-      return self.locks.tryAcquire(hash_, sync=True)
+      try:
+        return self.locks.tryAcquire(hash_, sync=True, timeout=self.acquire_timeout)
+      except SyncObjException: # timeout
+        return False
 
     def releaseJob(self, hash_: str):
       self.locks.release(hash_)
